==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/NetworkCardInfo.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  NetworkPerformance,
  BaselineBandwidthInGbps,
  MaxNetworkInterfaces,
  NetworkCardIndex,
  PeakBandwidthInGbps
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class NetworkCardInfo(
    networkCardIndex: Optional[NetworkCardIndex] = Optional.Absent,
    networkPerformance: Optional[NetworkPerformance] = Optional.Absent,
    maximumNetworkInterfaces: Optional[MaxNetworkInterfaces] = Optional.Absent,
    baselineBandwidthInGbps: Optional[BaselineBandwidthInGbps] =
      Optional.Absent,
    peakBandwidthInGbps: Optional[PeakBandwidthInGbps] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkCardInfo = {
    import NetworkCardInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkCardInfo
      .builder()
      .optionallyWith(
        networkCardIndex.map(value => NetworkCardIndex.unwrap(value): Integer)
      )(_.networkCardIndex)
      .optionallyWith(
        networkPerformance.map(value =>
          NetworkPerformance.unwrap(value): java.lang.String
        )
      )(_.networkPerformance)
      .optionallyWith(
        maximumNetworkInterfaces.map(value =>
          MaxNetworkInterfaces.unwrap(value): Integer
        )
      )(_.maximumNetworkInterfaces)
      .optionallyWith(
        baselineBandwidthInGbps.map(value =>
          BaselineBandwidthInGbps.unwrap(value): java.lang.Double
        )
      )(_.baselineBandwidthInGbps)
      .optionallyWith(
        peakBandwidthInGbps.map(value =>
          PeakBandwidthInGbps.unwrap(value): java.lang.Double
        )
      )(_.peakBandwidthInGbps)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkCardInfo.ReadOnly =
    zio.aws.ec2.model.NetworkCardInfo.wrap(buildAwsValue())
}
object NetworkCardInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkCardInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkCardInfo =
      zio.aws.ec2.model.NetworkCardInfo(
        networkCardIndex.map(value => value),
        networkPerformance.map(value => value),
        maximumNetworkInterfaces.map(value => value),
        baselineBandwidthInGbps.map(value => value),
        peakBandwidthInGbps.map(value => value)
      )
    def networkCardIndex: Optional[NetworkCardIndex]
    def networkPerformance: Optional[NetworkPerformance]
    def maximumNetworkInterfaces: Optional[MaxNetworkInterfaces]
    def baselineBandwidthInGbps: Optional[BaselineBandwidthInGbps]
    def peakBandwidthInGbps: Optional[PeakBandwidthInGbps]
    def getNetworkCardIndex: ZIO[Any, AwsError, NetworkCardIndex] =
      AwsError.unwrapOptionField("networkCardIndex", networkCardIndex)
    def getNetworkPerformance: ZIO[Any, AwsError, NetworkPerformance] =
      AwsError.unwrapOptionField("networkPerformance", networkPerformance)
    def getMaximumNetworkInterfaces: ZIO[Any, AwsError, MaxNetworkInterfaces] =
      AwsError.unwrapOptionField(
        "maximumNetworkInterfaces",
        maximumNetworkInterfaces
      )
    def getBaselineBandwidthInGbps
        : ZIO[Any, AwsError, BaselineBandwidthInGbps] = AwsError
      .unwrapOptionField("baselineBandwidthInGbps", baselineBandwidthInGbps)
    def getPeakBandwidthInGbps: ZIO[Any, AwsError, PeakBandwidthInGbps] =
      AwsError.unwrapOptionField("peakBandwidthInGbps", peakBandwidthInGbps)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkCardInfo
  ) extends zio.aws.ec2.model.NetworkCardInfo.ReadOnly {
    override val networkCardIndex: Optional[NetworkCardIndex] =
      zio.aws.core.internal
        .optionalFromNullable(impl.networkCardIndex())
        .map(value => zio.aws.ec2.model.primitives.NetworkCardIndex(value))
    override val networkPerformance: Optional[NetworkPerformance] =
      zio.aws.core.internal
        .optionalFromNullable(impl.networkPerformance())
        .map(value => zio.aws.ec2.model.primitives.NetworkPerformance(value))
    override val maximumNetworkInterfaces: Optional[MaxNetworkInterfaces] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maximumNetworkInterfaces())
        .map(value => zio.aws.ec2.model.primitives.MaxNetworkInterfaces(value))
    override val baselineBandwidthInGbps: Optional[BaselineBandwidthInGbps] =
      zio.aws.core.internal
        .optionalFromNullable(impl.baselineBandwidthInGbps())
        .map(value =>
          zio.aws.ec2.model.primitives.BaselineBandwidthInGbps(value)
        )
    override val peakBandwidthInGbps: Optional[PeakBandwidthInGbps] =
      zio.aws.core.internal
        .optionalFromNullable(impl.peakBandwidthInGbps())
        .map(value => zio.aws.ec2.model.primitives.PeakBandwidthInGbps(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkCardInfo
  ): zio.aws.ec2.model.NetworkCardInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.104.11-sources.jar: zio/aws/ec2/model/NetworkCardInfo.scala <==
package zio.aws.ec2.model
import java.lang.Integer
import zio.aws.ec2.model.primitives.{
  MaxNetworkInterfaces,
  NetworkPerformance,
  NetworkCardIndex
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class NetworkCardInfo(
    networkCardIndex: Option[NetworkCardIndex] = None,
    networkPerformance: Option[NetworkPerformance] = None,
    maximumNetworkInterfaces: Option[MaxNetworkInterfaces] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.NetworkCardInfo = {
    import NetworkCardInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.NetworkCardInfo
      .builder()
      .optionallyWith(
        networkCardIndex.map(value => NetworkCardIndex.unwrap(value): Integer)
      )(_.networkCardIndex)
      .optionallyWith(
        networkPerformance.map(value =>
          NetworkPerformance.unwrap(value): java.lang.String
        )
      )(_.networkPerformance)
      .optionallyWith(
        maximumNetworkInterfaces.map(value =>
          MaxNetworkInterfaces.unwrap(value): Integer
        )
      )(_.maximumNetworkInterfaces)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.NetworkCardInfo.ReadOnly =
    zio.aws.ec2.model.NetworkCardInfo.wrap(buildAwsValue())
}
object NetworkCardInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.NetworkCardInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.NetworkCardInfo =
      zio.aws.ec2.model.NetworkCardInfo(
        networkCardIndex.map(value => value),
        networkPerformance.map(value => value),
        maximumNetworkInterfaces.map(value => value)
      )
    def networkCardIndex: Option[NetworkCardIndex]
    def networkPerformance: Option[NetworkPerformance]
    def maximumNetworkInterfaces: Option[MaxNetworkInterfaces]
    def getNetworkCardIndex: ZIO[Any, AwsError, NetworkCardIndex] =
      AwsError.unwrapOptionField("networkCardIndex", networkCardIndex)
    def getNetworkPerformance: ZIO[Any, AwsError, NetworkPerformance] =
      AwsError.unwrapOptionField("networkPerformance", networkPerformance)
    def getMaximumNetworkInterfaces: ZIO[Any, AwsError, MaxNetworkInterfaces] =
      AwsError.unwrapOptionField(
        "maximumNetworkInterfaces",
        maximumNetworkInterfaces
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.NetworkCardInfo
  ) extends zio.aws.ec2.model.NetworkCardInfo.ReadOnly {
    override val networkCardIndex: Option[NetworkCardIndex] = scala
      .Option(impl.networkCardIndex())
      .map(value => zio.aws.ec2.model.primitives.NetworkCardIndex(value))
    override val networkPerformance: Option[NetworkPerformance] = scala
      .Option(impl.networkPerformance())
      .map(value => zio.aws.ec2.model.primitives.NetworkPerformance(value))
    override val maximumNetworkInterfaces: Option[MaxNetworkInterfaces] = scala
      .Option(impl.maximumNetworkInterfaces())
      .map(value => zio.aws.ec2.model.primitives.MaxNetworkInterfaces(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.NetworkCardInfo
  ): zio.aws.ec2.model.NetworkCardInfo.ReadOnly = new Wrapper(impl)
}
